ValidatorRelayClient

Struct ValidatorRelayClient 

pub struct ValidatorRelayClient<T> { /* private fields */ }
A service run by the proxy which forwards a shard’s requests to another validator.

Shards hold the validator’s secret key, so the proxy is the only component that opens outbound connections. A shard names the validator its request is meant for and the proxy performs it. Limited to the operations block export needs, so reaching this service does not confer the ability to make the proxy issue arbitrary requests.

Implementations

Source

impl ValidatorRelayClient<Channel>

pub async fn connect<D>(dst: D) -> Result<Self, Error>
where D: TryInto<Endpoint>, D::Error: Into<StdError>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> ValidatorRelayClient<T>
where T: GrpcService<Body>, T::Error: Into<StdError>, T::ResponseBody: Body<Data = Bytes> + Send + 'static, <T::ResponseBody as Body>::Error: Into<StdError> + Send,

pub fn new(inner: T) -> Self

pub fn with_origin(inner: T, origin: Uri) -> Self

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> ValidatorRelayClient<InterceptedService<T, F>>
where F: Interceptor, T::ResponseBody: Default, T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>, <T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,

pub fn send_compressed(self, encoding: CompressionEncoding) -> Self

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> Self

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> Self

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn relay_lite_certificate( &mut self, request: impl IntoRequest<RelayLiteCertificateRequest>, ) -> Result<Response<ChainInfoResult>, Status>

Forward a lite certificate to another validator.

pub async fn relay_confirmed_certificate( &mut self, request: impl IntoRequest<RelayConfirmedCertificateRequest>, ) -> Result<Response<ChainInfoResult>, Status>

Forward a confirmed certificate to another validator.

pub async fn relay_chain_info_query( &mut self, request: impl IntoRequest<RelayChainInfoQueryRequest>, ) -> Result<Response<ChainInfoResult>, Status>

Ask another validator for the state of a chain.

pub async fn relay_upload_blob( &mut self, request: impl IntoRequest<RelayUploadBlobRequest>, ) -> Result<Response<BlobId>, Status>

Upload a blob to another validator.