pub struct ValidatorRelayClient<T> { /* private fields */ }Expand description
A service run by the proxy which forwards a shard’s requests to another validator.
Shards hold the validator’s secret key, so the proxy is the only component that opens outbound connections. A shard names the validator its request is meant for and the proxy performs it. Limited to the operations block export needs, so reaching this service does not confer the ability to make the proxy issue arbitrary requests.
Implementations
Sourceimpl<T> ValidatorRelayClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> ValidatorRelayClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> ValidatorRelayClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn relay_lite_certificate(
&mut self,
request: impl IntoRequest<RelayLiteCertificateRequest>,
) -> Result<Response<ChainInfoResult>, Status>
pub async fn relay_lite_certificate( &mut self, request: impl IntoRequest<RelayLiteCertificateRequest>, ) -> Result<Response<ChainInfoResult>, Status>
Forward a lite certificate to another validator.
Sourcepub async fn relay_confirmed_certificate(
&mut self,
request: impl IntoRequest<RelayConfirmedCertificateRequest>,
) -> Result<Response<ChainInfoResult>, Status>
pub async fn relay_confirmed_certificate( &mut self, request: impl IntoRequest<RelayConfirmedCertificateRequest>, ) -> Result<Response<ChainInfoResult>, Status>
Forward a confirmed certificate to another validator.
Sourcepub async fn relay_chain_info_query(
&mut self,
request: impl IntoRequest<RelayChainInfoQueryRequest>,
) -> Result<Response<ChainInfoResult>, Status>
pub async fn relay_chain_info_query( &mut self, request: impl IntoRequest<RelayChainInfoQueryRequest>, ) -> Result<Response<ChainInfoResult>, Status>
Ask another validator for the state of a chain.
Sourcepub async fn relay_upload_blob(
&mut self,
request: impl IntoRequest<RelayUploadBlobRequest>,
) -> Result<Response<BlobId>, Status>
pub async fn relay_upload_blob( &mut self, request: impl IntoRequest<RelayUploadBlobRequest>, ) -> Result<Response<BlobId>, Status>
Upload a blob to another validator.